==> iobroker.google-sharedlocations-1.2.0.tgz: package/admin/words.js <==
/*global systemDictionary:true */
'use strict';

systemDictionary = {
  "center_lat": {
    "en": "Center Latitude (decimal)",
    "de": "Breitengrad (dezimal)",
    "ru": "Широта центра (десятичная)",
    "pt": "Latitude Central (decimal)",
    "nl": "Midden-breedtegraad (decimaal)",
    "fr": "Latitude centrale (décimale)",
    "it": "Center Latitude (decimale)",
    "es": "Latitud central (decimal)",
    "pl": "Środkowa szerokość geograficzna (dziesiętna)"
  },
  "center_long": {
    "en": "Center Longitude (decimal)",
    "de": "Längengrad (dezimal)",
    "ru": "Центральная долгота (десятичная)",
    "pt": "Longitude do centro (decimal)",
    "nl": "Middenlengtegraad (decimaal)",
    "fr": "Longitude du centre (décimal)",
    "it": "Center Longitude (decimale)",
    "es": "Longitud del centro (decimal)",
    "pl": "Centrum długość geograficzna (dziesiętna)"
  },
  "description": {
    "en": "description",
    "de": "Beschreibung",
    "ru": "описание",
    "pt": "descrição",
    "nl": "Beschrijving",
    "fr": "la description",
    "it": "descrizione",
    "es": "descripción",
    "pl": "opis"
  },
  "geofences": {
    "en": "Geofences",
    "de": "Geofences",
    "ru": "Геозоны",
    "pt": "Cercas Geográficas",
    "nl": "geofences",
    "fr": "Geofences",
    "it": "geofences",
    "es": "Geofences",
    "pl": "Geofences"
  },
  "main settings": {
    "en": "Settings",
    "de": "Einstellungen",
    "ru": "настройки",
    "pt": "Configurações",
    "nl": "instellingen",
    "fr": "Paramètres",
    "it": "impostazioni",
    "es": "Configuraciones",
    "pl": "Ustawienia"
  },
  "google sharedlocations settings": {
    "en": "Google sharedlocations adapter settings",
    "de": "Google sharedlocations Adaptereinstellungen",
    "ru": "Настройки адаптера Google sharedlocations",
    "pt": "Configurações do adaptador de locais compartilhados do Google",
    "nl": "Google sharedlocations-adapterinstellingen",
    "fr": "Paramètres de la carte de partage de partage Google",
    "it": "Impostazioni della scheda sharedlocations di Google",
    "es": "Configuración del adaptador de ubicación compartida de Google",
    "pl": "Ustawienia adaptera Google sharedlocations"
  },
  "google_password": {
    "en": "Password",
    "de": "Passwort",
    "ru": "пароль",
    "pt": "Senha",
    "nl": "Wachtwoord",
    "fr": "Mot de passe",
    "it": "Parola d'ordine",
    "es": "Contraseña",
    "pl": "Hasło"
  },
  "google_polling_interval": {
    "en": "Polling interval (s)",
    "de": "Abrufintervall (e)",
    "ru": "Интервал опроса (ов)",
    "pt": "Intervalo (s) de pesquisa",
    "nl": "Polling-interval (sen)",
    "fr": "Intervalle d'interrogation",
    "it": "Intervallo di polling",
    "es": "Intervalo (s) de sondeo",
    "pl": "Interwały sondowania"
  },
  "google_username": {
    "en": "Username",
    "de": "Nutzername",
    "ru": "имя пользователя",
    "pt": "Nome de usuário",
    "nl": "Gebruikersnaam",
    "fr": "Nom d'utilisateur",
    "it": "Nome utente",
    "es": "Nombre de usuario",
    "pl": "Nazwa Użytkownika"
  },
  "google_verify_email": {
    "en": "Recovery email address",
    "de": "Email zur Kontowiederherstellung",
    "ru": "Восстановить адрес электронной почты",
    "pt": "Endereço de e-mail de recuperação",
    "nl": "Herstel e-mailadres",
    "fr": "Adresse mail de secours",
    "it": "Indirizzo email di recupero",
    "es": "Dirección de correo electrónico de recuperación",
    "pl": "Odzyskiwanie adres e-mail"
  },
  "login_data": {
    "en": "Login data",
    "de": "Anmeldedaten",
    "ru": "Входные данные",
    "pt": "Dados de login",
    "nl": "Aanmeldgegevens",
    "fr": "Données de connexion",
    "it": "Dati di accesso",
    "es": "Datos de ingreso",
    "pl": "Dane logowania"
  },
  "on save adapter restarts with new config immediately": {
    "en": "on save adapter restarts with new config immediately",
    "de": "Beim Speichern wird der Adapter sofort mit der neuen Konfiguration neu gestartet",
    "ru": "на перезаписываемом адаптере перезагружается с новой конфигурацией немедленно",
    "pt": "on save adapter reinicia com nova configuração imediatamente",
    "nl": "on save-adapter wordt onmiddellijk opnieuw opgestart met nieuwe config",
    "fr": "sur la sauvegarde de l'adaptateur redémarre immédiatement avec la nouvelle configuration",
    "it": "su save adapter si riavvia immediatamente con la nuova configurazione",
    "es": "en el adaptador de guardar se reinicia con nueva configuración de inmediato",
    "pl": "na karcie save natychmiast uruchamia się z nową konfiguracją"
  },
  "places_adapter": {
    "en": "Places instance",
    "de": "Orte Instanz",
    "ru": "Экземпляр экземпляров",
    "pt": "Instância de lugares",
    "nl": "Places-instantie",
    "fr": "Instance de lieux",
    "it": "Luoghi di istanza",
    "es": "Instancia de lugares",
    "pl": "Instancja miejsca"
  },
  "radius": {
    "en": "radius (m)",
    "de": "Radius (m)",
    "ru": "радиус (м)",
    "pt": "raio (m)",
    "nl": "straal (m)",
    "fr": "rayon (m)",
    "it": "raggio (m)",
    "es": "radio (m)",
    "pl": "promień (m)"
  },
  "search": {
    "en": "search",
    "de": "Suche",
    "ru": "поиск",
    "pt": "pesquisa",
    "nl": "zoeken",
    "fr": "chercher",
    "it": "ricerca",
    "es": "buscar",
    "pl": "Szukaj"
  },
  "userid": {
    "en": "user id",
    "de": "Benutzeridentifikation",
    "ru": "Идентификатор пользователя",
    "pt": "ID do usuário",
    "nl": "gebruikersnaam",
    "fr": "identifiant d'utilisateur",
    "it": "ID utente",
    "es": "identidad de usuario",
    "pl": "identyfikator użytkownika"
  },
  "user": {
    "en": "user",
    "de": "Benutzer",
    "ru": "пользователь",
    "pt": "do utilizador",
    "nl": "gebruiker",
    "fr": "utilisateur",
    "it": "utente",
    "es": "usuario",
    "pl": "użytkownik"
  },
  "check_connection": {
    "en": "check connection",
    "de": "Verbindung prüfen",
    "ru": "Проверьте подключение",
    "pt": "verifique a conexão",
    "nl": "controleer de verbinding",
    "fr": "vérifier la connexion",
    "it": "controllare la connessione",
    "es": "verifica la conexión",
    "pl": "Sprawdź połączenie"
  },
  "none": {
    "en": "none",
    "de": "keine",
    "ru": "никто",
    "pt": "Nenhum",
    "nl": "geen",
    "fr": "aucun",
    "it": "nessuna",
    "es": "ninguna",
    "pl": "Żaden"
  },
  "foreignadapters": {
    "en": "Other adapters",
    "de": "Andere Adapter",
    "ru": "Другие адаптеры",
    "pt": "Outros adaptadores",
    "nl": "Andere adapters",
    "fr": "Autres adaptateurs",
    "it": "Altri adattatori",
    "es": "Otros adaptadores",
    "pl": "Inne adaptery"
  }
};

==> iobroker.google-sharedlocations-1.5.1.tgz: package/admin/words.js <==
/*global systemDictionary:true */
'use strict';

systemDictionary = {
  "center_lat": {
    "en": "Center Latitude (decimal)",
    "de": "Breitengrad (dezimal)",
    "ru": "Широта центра (десятичная)",
    "pt": "Latitude Central (decimal)",
    "nl": "Midden-breedtegraad (decimaal)",
    "fr": "Latitude centrale (décimale)",
    "it": "Center Latitude (decimale)",
    "es": "Latitud central (decimal)",
    "pl": "Środkowa szerokość geograficzna (dziesiętna)"
  },
  "center_long": {
    "en": "Center Longitude (decimal)",
    "de": "Längengrad (dezimal)",
    "ru": "Центральная долгота (десятичная)",
    "pt": "Longitude do centro (decimal)",
    "nl": "Middenlengtegraad (decimaal)",
    "fr": "Longitude du centre (décimal)",
    "it": "Center Longitude (decimale)",
    "es": "Longitud del centro (decimal)",
    "pl": "Centrum długość geograficzna (dziesiętna)"
  },
  "description": {
    "en": "description",
    "de": "Beschreibung",
    "ru": "описание",
    "pt": "descrição",
    "nl": "Beschrijving",
    "fr": "la description",
    "it": "descrizione",
    "es": "descripción",
    "pl": "opis"
  },
  "fenceid": {
    "en": "Fence id",
    "de": "Zaun ID",
    "ru": "Идентификатор ограждения",
    "pt": "ID da cerca",
    "nl": "Fence id",
    "fr": "ID de clôture",
    "it": "Recinzione id",
    "es": "ID de valla",
    "pl": "Płot id"
  },
  "geofences": {
    "en": "Geofences",
    "de": "Geofences",
    "ru": "Геозоны",
    "pt": "Cercas Geográficas",
    "nl": "geofences",
    "fr": "Geofences",
    "it": "geofences",
    "es": "Geofences",
    "pl": "Geofences"
  },
  "main settings": {
    "en": "Settings",
    "de": "Einstellungen",
    "ru": "настройки",
    "pt": "Configurações",
    "nl": "instellingen",
    "fr": "Paramètres",
    "it": "impostazioni",
    "es": "Configuraciones",
    "pl": "Ustawienia"
  },
  "google sharedlocations settings": {
    "en": "Google sharedlocations adapter settings",
    "de": "Google sharedlocations Adaptereinstellungen",
    "ru": "Настройки адаптера Google sharedlocations",
    "pt": "Configurações do adaptador de locais compartilhados do Google",
    "nl": "Google sharedlocations-adapterinstellingen",
    "fr": "Paramètres de la carte de partage de partage Google",
    "it": "Impostazioni della scheda sharedlocations di Google",
    "es": "Configuración del adaptador de ubicación compartida de Google",
    "pl": "Ustawienia adaptera Google sharedlocations"
  },
  "google_password": {
    "en": "Password",
    "de": "Passwort",
    "ru": "пароль",
    "pt": "Senha",
    "nl": "Wachtwoord",
    "fr": "Mot de passe",
    "it": "Parola d'ordine",
    "es": "Contraseña",
    "pl": "Hasło"
  },
  "google_polling_interval": {
    "en": "Polling interval (s), 0 = disabled",
    "de": "Abrufintervall (s), 0 = deaktiviert",
    "ru": "Интервал опроса (ы), 0 = отключен",
    "pt": "Intervalo de sondagem (s), 0 = desativado",
    "nl": "Polling-interval (s), 0 = uitgeschakeld",
    "fr": "Intervalle d'interrogation (s), 0 = désactivé",
    "it": "Intervallo di polling (s), 0 = disabilitato",
    "es": "Intervalo de sondeo (s), 0 = deshabilitado",
    "pl": "Interwał odpytywania (s), 0 = wyłączony"
  },
  "google_username": {
    "en": "Username",
    "de": "Nutzername",
    "ru": "имя пользователя",
    "pt": "Nome de usuário",
    "nl": "Gebruikersnaam",
    "fr": "Nom d'utilisateur",
    "it": "Nome utente",
    "es": "Nombre de usuario",
    "pl": "Nazwa Użytkownika"
  },
  "google_verify_email": {
    "en": "Recovery email address",
    "de": "Email zur Kontowiederherstellung",
    "ru": "Восстановить адрес электронной почты",
    "pt": "Endereço de e-mail de recuperação",
    "nl": "Herstel e-mailadres",
    "fr": "Adresse mail de secours",
    "it": "Indirizzo email di recupero",
    "es": "Dirección de correo electrónico de recuperación",
    "pl": "Odzyskiwanie adres e-mail"
  },
  "login_data": {
    "en": "Login data",
    "de": "Anmeldedaten",
    "ru": "Входные данные",
    "pt": "Dados de login",
    "nl": "Aanmeldgegevens",
    "fr": "Données de connexion",
    "it": "Dati di accesso",
    "es": "Datos de ingreso",
    "pl": "Dane logowania"
  },
  "on save adapter restarts with new config immediately": {
    "en": "on save adapter restarts with new config immediately",
    "de": "Beim Speichern wird der Adapter sofort mit der neuen Konfiguration neu gestartet",
    "ru": "на перезаписываемом адаптере перезагружается с новой конфигурацией немедленно",
    "pt": "on save adapter reinicia com nova configuração imediatamente",
    "nl": "on save-adapter wordt onmiddellijk opnieuw opgestart met nieuwe config",
    "fr": "sur la sauvegarde de l'adaptateur redémarre immédiatement avec la nouvelle configuration",
    "it": "su save adapter si riavvia immediatamente con la nuova configurazione",
    "es": "en el adaptador de guardar se reinicia con nueva configuración de inmediato",
    "pl": "na karcie save natychmiast uruchamia się z nową konfiguracją"
  },
  "places_adapter": {
    "en": "Places instance",
    "de": "Orte Instanz",
    "ru": "Экземпляр экземпляров",
    "pt": "Instância de lugares",
    "nl": "Places-instantie",
    "fr": "Instance de lieux",
    "it": "Luoghi di istanza",
    "es": "Instancia de lugares",
    "pl": "Instancja miejsca"
  },
  "radius": {
    "en": "radius (m)",
    "de": "Radius (m)",
    "ru": "радиус (м)",
    "pt": "raio (m)",
    "nl": "straal (m)",
    "fr": "rayon (m)",
    "it": "raggio (m)",
    "es": "radio (m)",
    "pl": "promień (m)"
  },
  "search": {
    "en": "search",
    "de": "Suche",
    "ru": "поиск",
    "pt": "pesquisa",
    "nl": "zoeken",
    "fr": "chercher",
    "it": "ricerca",
    "es": "buscar",
    "pl": "Szukaj"
  },
  "userid": {
    "en": "user id",
    "de": "Benutzeridentifikation",
    "ru": "Идентификатор пользователя",
    "pt": "ID do usuário",
    "nl": "gebruikersnaam",
    "fr": "identifiant d'utilisateur",
    "it": "ID utente",
    "es": "identidad de usuario",
    "pl": "identyfikator użytkownika"
  },
  "user": {
    "en": "user",
    "de": "Benutzer",
    "ru": "пользователь",
    "pt": "do utilizador",
    "nl": "gebruiker",
    "fr": "utilisateur",
    "it": "utente",
    "es": "usuario",
    "pl": "użytkownik"
  },
  "check_connection": {
    "en": "check connection",
    "de": "Verbindung prüfen",
    "ru": "Проверьте подключение",
    "pt": "verifique a conexão",
    "nl": "controleer de verbinding",
    "fr": "vérifier la connexion",
    "it": "controllare la connessione",
    "es": "verifica la conexión",
    "pl": "Sprawdź połączenie"
  },
  "none": {
    "en": "none",
    "de": "keine",
    "ru": "никто",
    "pt": "Nenhum",
    "nl": "geen",
    "fr": "aucun",
    "it": "nessuna",
    "es": "ninguna",
    "pl": "Żaden"
  },
  "foreignadapters": {
    "en": "Other adapters",
    "de": "Andere Adapter",
    "ru": "Другие адаптеры",
    "pt": "Outros adaptadores",
    "nl": "Andere adapters",
    "fr": "Autres adaptateurs",
    "it": "Altri adattatori",
    "es": "Otros adaptadores",
    "pl": "Inne adaptery"
  }
};
